@@ -47,14 +47,17 @@ class TqdmWarning(Warning):
     """
     def __init__(self, msg, fp_write=None, *a, **k):
         if fp_write is not None:
-            fp_write("\n" + self.__class__.__name__ + ": " + str(msg).rstrip() + '\n')
+            fp_write("\n" + self.__class__.__name__ + ": " +
+                     str(msg).rstrip() + '\n')
         else:
             super(TqdmWarning, self).__init__(msg, *a, **k)
 
+
 class TqdmExperimentalWarning(TqdmWarning, FutureWarning):
     """beta feature, unstable API and behaviour"""
     pass
 
+
 class TqdmDeprecationWarning(TqdmWarning, DeprecationWarning):
     # not suppressed if raised
     pass
@@ -542,6 +545,11 @@ class tqdm(object):
         from pandas.core.groupby import GroupBy
         from pandas.core.groupby import PanelGroupBy
         from pandas import Panel
+        try:
+            # pandas>=0.18.0
+            from pandas.core.window import _Rolling_and_Expanding
+        except ImportError:  # pragma: no cover
+            _Rolling_and_Expanding = None
 
         deprecated_t = [tkwargs.pop('deprecated_t', None)]
 
@@ -559,13 +567,15 @@ class tqdm(object):
                 """
 
                 # Precompute total iterations
-                total = getattr(df, 'ngroups', None)
+                total = tkwargs.pop("total", getattr(df, 'ngroups', None))
                 if total is None:  # not grouped
                     if df_function == 'applymap':
                         total = df.size
                     elif isinstance(df, Series):
                         total = len(df)
-                    else:  # DataFrame or Panel
+                    elif _Rolling_and_Expanding is None or \
+                            not isinstance(df, _Rolling_and_Expanding):
+                        # DataFrame or Panel
                         axis = kwargs.get('axis', 0)
                         # when axis=0, total is shape[axis1]
                         total = df.size // df.shape[axis]
@@ -592,7 +602,7 @@ class tqdm(object):
                     # it seems `pandas apply` calls `func` twice
                     # on the first column/row to decide whether it can
                     # take a fast or slow code path; so stop when t.total==t.n
-                    t.update(n=1 if t.total and t.n < t.total else 0)
+                    t.update(n=1 if not t.total or t.n < t.total else 0)
                     return func(*args, **kwargs)
 
                 # Apply the provided function (in **kwargs)
@@ -623,6 +633,9 @@ class tqdm(object):
         GroupBy.progress_aggregate = inner_generator('aggregate')
         GroupBy.progress_transform = inner_generator('transform')
 
+        if _Rolling_and_Expanding is not None:  # pragma: no cover
+            _Rolling_and_Expanding.progress_apply = inner_generator()
+
     def __init__(self, iterable=None, desc=None, total=None, leave=True,
                  file=None, ncols=None, mininterval=0.1, maxinterval=10.0,
                  miniters=None, ascii=None, disable=False, unit='it',
@@ -853,7 +866,7 @@ class tqdm(object):
         return self.total if self.iterable is None else \
             (self.iterable.shape[0] if hasattr(self.iterable, "shape")
              else len(self.iterable) if hasattr(self.iterable, "__len__")
-             else self.total)
+             else getattr(self, "total", None))
 
     def __enter__(self):
         return self
